stoq Package
============

:mod:`stoq` Package
-------------------

.. automodule:: stoq.__init__
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`dbadmin` Module
---------------------

.. automodule:: stoq.dbadmin
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`main` Module
------------------

.. automodule:: stoq.main
    :members:
    :undoc-members:
    :show-inheritance:

Subpackages
-----------

.. toctree::

    stoq.gui
    stoq.lib

